@@ -326,8 +326,13 @@ public:
     parent_node= child_head = child_tail = next_sibling = prev_sibling = NULL;
   }; 
 
+#ifdef GLUI211 /* friend class declaration */
+  friend class GLUI_Rollout;
+  friend class GLUI_Main;
+#else
   friend GLUI_Rollout;
   friend GLUI_Main;
+#endif
 };
 
 
@@ -590,11 +595,19 @@ protected:
 
   /********** Friend classes *************/
 
+#ifdef GLUI211 /* friend class declaration */
+  friend class GLUI_Control;
+  friend class GLUI_Rotation;
+  friend class GLUI_Translation;
+  friend class GLUI;
+  friend class GLUI_Master_Object;
+#else
   friend GLUI_Control;
   friend GLUI_Rotation;
   friend GLUI_Translation;
   friend GLUI;
   friend GLUI_Master_Object;
+#endif
 
 
   /********** Misc functions *************/
